Layer Cake Example
===

This is a starter example for using [Layer Cake](https://layercake.graphics). It sets you up with the line and area chart as seen [in the examples](https://layercake.graphics/example/Line). 

To create a new project based on this template using [degit](https://github.com/Rich-Harris/degit):

```bash
npx degit mhkeller/layercake-template my-chart
cd my-chart
```

*Note that you will need to have [Node.js](https://nodejs.org) installed.*

## Get started

Install the dependencies...

```bash
npm install
npm run build && npm run preview
```

Your app will be running at [localhost:4173](http://localhost:4173).

## Developing

```sh
# if you didn't already install, run the install command
npm install
npm run dev
```

Your app will be running at [localhost:5173](http://localhost:5173).


## Prod

```
npm run build
```

Then use flask to serve the app.

```
FLASK_APP=serve.py flask run
```